import { NetlifyAPI } from 'netlify';
import { ModeOption, TestOptions } from '../types/options.js';
type GetSiteInfoOpts = {
    siteId: string;
    accountId?: string;
    mode: ModeOption;
    offline?: boolean;
    api?: NetlifyAPI;
    context?: string;
    featureFlags?: Record<string, boolean>;
    testOpts?: TestOptions;
    siteFeatureFlagPrefix: string;
};
/**
 * Retrieve Netlify Site information, if available.
 * Used to retrieve local build environment variables and UI build settings.
 * This is not used in production builds since the buildbot passes this
 * information instead.
 * Requires knowing the `siteId` and having the access `token`.
 * Silently ignore API errors. For example the network connection might be down,
 * but local builds should still work regardless.
 */
export declare const getSiteInfo: ({ api, siteId, accountId, mode, context, offline, testOpts, featureFlags, siteFeatureFlagPrefix, }: GetSiteInfoOpts) => Promise<{
    siteInfo: any;
    accounts: any;
    addons: any;
    integrations: any;
}>;
export {};
