const getCustomErrorInfo = (options) => ({
    location: {
        format: options === null || options === void 0 ? void 0 : options.format,
        runtime: 'deno',
    },
    type: 'functionsBundling',
});
class BundleError extends Error {
    constructor(originalError, options) {
        super(originalError.message);
        this.customErrorInfo = getCustomErrorInfo(options);
        this.name = 'BundleError';
        this.stack = originalError.stack;
        // https://github.com/microsoft/TypeScript-wiki/blob/8a66ecaf77118de456f7cd9c56848a40fe29b9b4/Breaking-Changes.md#implicit-any-error-raised-for-un-annotated-callback-arguments-with-no-matching-overload-arguments
        Object.setPrototypeOf(this, BundleError.prototype);
    }
}
/**
 * BundleErrors are treated as user-error, so Netlify Team is not alerted about them.
 */
const wrapBundleError = (input, options) => {
    if (input instanceof Error) {
        if (input.message.includes("The module's source code could not be parsed")) {
            input.message = input.stderr;
        }
        return new BundleError(input, options);
    }
    return input;
};
export { BundleError, wrapBundleError };
