import { DenoBridge } from './bridge.js';
import { EdgeFunction } from './edge_function.js';
import { ImportMap } from './import_map.js';
import { Logger } from './logger.js';
import { RateLimit } from './rate_limit.js';
export declare const enum Cache {
    Off = "off",
    Manual = "manual"
}
export type HTTPMethod = 'GET' | 'POST' | 'PUT' | 'PATCH' | 'DELETE' | 'OPTIONS';
export type Path = `/${string}`;
export type OnError = 'fail' | 'bypass' | Path;
export declare const isValidOnError: (value: unknown) => value is OnError;
interface BaseFunctionConfig {
    cache?: Cache;
    onError?: OnError;
    name?: string;
    generator?: string;
    method?: HTTPMethod | HTTPMethod[];
    rateLimit?: RateLimit;
}
interface FunctionConfigWithPath extends BaseFunctionConfig {
    path?: Path | Path[];
    excludedPath?: Path | Path[];
}
interface FunctionConfigWithPattern extends BaseFunctionConfig {
    pattern: string | string[];
    excludedPattern?: string | string[];
}
export type FunctionConfig = FunctionConfigWithPath | FunctionConfigWithPattern;
export type FunctionConfigWithAllPossibleFields = BaseFunctionConfig & Partial<FunctionConfigWithPath & FunctionConfigWithPattern>;
export declare const getFunctionConfig: ({ func, importMap, deno, log, }: {
    func: EdgeFunction;
    importMap: ImportMap;
    deno: DenoBridge;
    log: Logger;
}) => Promise<FunctionConfig>;
export {};
